CCFLAGS = ['-I/usr/include/lua5.1', '-O2', '-ansi', '-Wall', '-g', '-D_REENTRANT', '-fPIC']
LIBPATH = ['/usr/lib']
LIBS = ['lua5.1']
prefix = '/usr'
build_dev = 1
#shared = 1
tolua_bin = 'tolua++5.1'
tolua_lib = 'tolua++5.1'
TOLUAPP = 'tolua++5.1'
